@@ -218,7 +218,7 @@ class DOMNode(MessagePump):
         self._has_hover_style: bool = False
         self._has_focus_within: bool = False
         self._reactive_connect: (
-            dict[str, tuple[MessagePump, Reactive | object]] | None
+            dict[str, tuple[MessagePump, Reactive[object] | object]] | None
         ) = None
         self._pruning = False
         self._query_one_cache: LRUCache[QueryOneCacheKey, DOMNode] = LRUCache(1024)
@@ -489,6 +489,11 @@ class DOMNode(MessagePump):
         """Is the node a modal?"""
         return False
 
+    @property
+    def is_on_screen(self) -> bool:
+        """Check if the node was displayed in the last screen update."""
+        return False
+
     def automatic_refresh(self) -> None:
         """Perform an automatic refresh.
 
@@ -497,7 +502,7 @@ class DOMNode(MessagePump):
         during an automatic refresh.
 
         """
-        if self.display and self.visible:
+        if self.is_on_screen:
             self.refresh()
 
     def __init_subclass__(
@@ -620,12 +625,13 @@ class DOMNode(MessagePump):
                         base.__dict__.get("BINDINGS", []),
                     )
                 )
+
         keys: dict[str, list[Binding]] = {}
         for bindings_ in bindings:
             for key, key_bindings in bindings_.key_to_bindings.items():
                 keys[key] = key_bindings
 
-        new_bindings = BindingsMap().from_keys(keys)
+        new_bindings = BindingsMap.from_keys(keys)
         return new_bindings
 
     def _post_register(self, app: App) -> None:
