@@ -13,7 +13,7 @@ import rich.repr
 from rich.style import Style
 from rich.text import Text
 
-from .cache import LRUCache
+from textual.cache import LRUCache
 
 
 @rich.repr.auto
@@ -103,7 +103,7 @@ class Matcher:
             A [rich.text.Text][`Text`] object with highlighted matches.
         """
         match = self._query_regex.search(candidate)
-        text = Text(candidate)
+        text = Text.from_markup(candidate)
         if match is None:
             return text
         assert match.lastindex is not None
