@@ -146,7 +146,7 @@ class Button(Widget, can_focus=True):
     }
     """
 
-    BINDINGS = [Binding("enter", "press", "Press Button", show=False)]
+    BINDINGS = [Binding("enter", "press", "Press button", show=False)]
 
     label: reactive[TextType] = reactive[TextType]("")
     """The text label that appears within the button."""
