@@ -6,14 +6,14 @@ from typing import TYPE_CHECKING
 import rich.repr
 from rich.text import Text
 
-from ..app import ComposeResult
-from ..binding import Binding
-from ..containers import ScrollableContainer
-from ..reactive import reactive
-from ..widget import Widget
+from textual.app import ComposeResult
+from textual.binding import Binding
+from textual.containers import ScrollableContainer
+from textual.reactive import reactive
+from textual.widget import Widget
 
 if TYPE_CHECKING:
-    from ..screen import Screen
+    from textual.screen import Screen
 
 
 @rich.repr.auto
@@ -69,12 +69,10 @@ class FooterKey(Widget):
             .footer-key--description {
                 padding: 0 0 0 1;
             }
-        }
+        }        
     }
     """
 
-    upper_case_keys = reactive(False)
-    ctrl_to_caret = reactive(True)
     compact = reactive(True)
 
     def __init__(
@@ -84,13 +82,19 @@ class FooterKey(Widget):
         description: str,
         action: str,
         disabled: bool = False,
+        tooltip: str = "",
+        classes="",
     ) -> None:
         self.key = key
         self.key_display = key_display
         self.description = description
         self.action = action
         self._disabled = disabled
-        super().__init__(classes="-disabled" if disabled else "")
+        if disabled:
+            classes += " -disabled"
+        super().__init__(classes=classes)
+        if tooltip:
+            self.tooltip = tooltip
 
     def render(self) -> Text:
         key_style = self.get_component_rich_style("footer-key--key")
@@ -100,10 +104,6 @@ class FooterKey(Widget):
         description_padding = self.get_component_styles(
             "footer-key--description"
         ).padding
-        if self.upper_case_keys:
-            key_display = key_display.upper()
-        if self.ctrl_to_caret and key_display.lower().startswith("ctrl+"):
-            key_display = "^" + key_display.split("+", 1)[1]
         description = self.description
         label_text = Text.assemble(
             (
@@ -144,53 +144,122 @@ class Footer(ScrollableContainer, can_focus=False, can_focus_children=False):
         &.-compact {
             grid-gutter: 1;
         }
+        FooterKey.-command-palette  {
+            dock: right;                        
+            padding-right: 1;
+            border-left: vkey $foreground 20%;                            
+        }
+
+        &.-ansi-colors {           
+            background: ansi_default;            
+            .footer-key--key {
+                background: ansi_default;
+                color: ansi_magenta;                
+            }
+            .footer-key--description {
+                background: ansi_default;
+                color: ansi_default;                
+            }
+            FooterKey:hover {
+                text-style: underline;
+                background: ansi_default;
+                color: ansi_default;
+                .footer-key--key {
+                    background: ansi_default;
+                }
+            }        
+            FooterKey.-command-palette {
+                background: ansi_default;
+                border-left: vkey ansi_black;
+            }
+        }
     }
     """
 
-    upper_case_keys = reactive(False)
-    """Upper case key display."""
-    ctrl_to_caret = reactive(True)
-    """Convert 'ctrl+' prefix to '^'."""
     compact = reactive(False)
     """Display in compact style."""
     _bindings_ready = reactive(False, repaint=False)
     """True if the bindings are ready to be displayed."""
+    show_command_palette = reactive(True)
+    """Show the key to invoke the command palette."""
+
+    def __init__(
+        self,
+        *children: Widget,
+        name: str | None = None,
+        id: str | None = None,
+        classes: str | None = None,
+        disabled: bool = False,
+        show_command_palette: bool = True,
+    ) -> None:
+        """A footer to show key bindings.
+
+        Args:
+            *children: Child widgets.
+            name: The name of the widget.
+            id: The ID of the widget in the DOM.
+            classes: The CSS classes for the widget.
+            disabled: Whether the widget is disabled or not.
+            show_command_palette: Show key binding to command palette, on the right of the footer.
+        """
+        super().__init__(
+            *children,
+            name=name,
+            id=id,
+            classes=classes,
+            disabled=disabled,
+        )
+        self.set_reactive(Footer.show_command_palette, show_command_palette)
 
     def compose(self) -> ComposeResult:
         if not self._bindings_ready:
             return
         bindings = [
-            (binding, enabled)
-            for (_, binding, enabled) in self.screen.active_bindings.values()
+            (binding, enabled, tooltip)
+            for (_, binding, enabled, tooltip) in self.screen.active_bindings.values()
             if binding.show
         ]
-        action_to_bindings: defaultdict[str, list[tuple[Binding, bool]]]
+        action_to_bindings: defaultdict[str, list[tuple[Binding, bool, str]]]
         action_to_bindings = defaultdict(list)
-        for binding, enabled in bindings:
-            action_to_bindings[binding.action].append((binding, enabled))
+        for binding, enabled, tooltip in bindings:
+            action_to_bindings[binding.action].append((binding, enabled, tooltip))
 
         self.styles.grid_size_columns = len(action_to_bindings)
         for multi_bindings in action_to_bindings.values():
-            binding, enabled = multi_bindings[0]
+            binding, enabled, tooltip = multi_bindings[0]
             yield FooterKey(
                 binding.key,
-                binding.key_display or self.app.get_key_display(binding.key),
+                self.app.get_key_display(binding),
                 binding.description,
                 binding.action,
                 disabled=not enabled,
-            ).data_bind(
-                Footer.upper_case_keys,
-                Footer.ctrl_to_caret,
-                Footer.compact,
-            )
+                tooltip=tooltip,
+            ).data_bind(Footer.compact)
+        if self.show_command_palette and self.app.ENABLE_COMMAND_PALETTE:
+            for key, binding in self.app._bindings:
+                if binding.action in (
+                    "app.command_palette",
+                    "command_palette",
+                ):
+                    yield FooterKey(
+                        key,
+                        self.app.get_key_display(binding),
+                        binding.description,
+                        binding.action,
+                        classes="-command-palette",
+                        tooltip=binding.tooltip or binding.description,
+                    )
+                    break
+
+    async def bindings_changed(self, screen: Screen) -> None:
+        self._bindings_ready = True
+        if not screen.app.app_focus:
+            return
+        if self.is_attached and screen is self.screen:
+            await self.recompose()
 
     def on_mount(self) -> None:
-        async def bindings_changed(screen: Screen) -> None:
-            self._bindings_ready = True
-            if self.is_attached and screen is self.screen:
-                await self.recompose()
-
-        self.screen.bindings_updated_signal.subscribe(self, bindings_changed)
+        self.screen.bindings_updated_signal.subscribe(self, self.bindings_changed)
 
     def on_unmount(self) -> None:
         self.screen.bindings_updated_signal.unsubscribe(self)
